<?php

add_action( 'admin_init', 'beautifuldecay_options_init' );
add_action( 'admin_menu', 'beautifuldecay_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function beautifuldecay_options_init(){
	register_setting( 'beautifuldecay_options', 'beautifuldecay_theme_options', 'beautifuldecay_options_validate' );
}

/**
 * Load up the menu page
 */
function beautifuldecay_options_add_page() {
	add_theme_page( __( 'Theme Options', 'beautifuldecay' ), __( 'Theme Options', 'beautifuldecay' ), 'edit_theme_options', 'theme_options', 'beautifuldecay_options_do_page' );
}

/**
 * Create the options page
 */
function beautifuldecay_options_do_page() {

	if ( ! isset( $_REQUEST['settings-updated'] ) )
		$_REQUEST['settings-updated'] = false;
	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" . wp_get_theme() . __( ' Theme Options', 'beautifuldecay' ) . "</h2>"; ?>
		<p><?php _e( 'These options will let you setup the social icons at the top of the theme. You can enter the URLs of your profiles to have the icons show up.', 'beautifuldecay' ); ?></p>
		<?php if ( false !== $_REQUEST['settings-updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved', 'beautifuldecay' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'beautifuldecay_options' ); ?>
			<?php $options = get_option( 'beautifuldecay_theme_options' ); ?>

			<table class="form-table">


				<?php
				/**
				 * Your Facebook Link
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Enter your Facebook URL', 'beautifuldecay' ); ?></th>
					<td>
						<input id="beautifuldecay_theme_options[facebookurl]" class="regular-text" type="text" name="beautifuldecay_theme_options[facebookurl]" value="<?php echo esc_url( $options['facebookurl'] ); ?>" />
						<label class="description" for="beautifuldecay_theme_options[facebookurl]"><?php _e( 'Leave blank to hide Facebook Icon', 'beautifuldecay' ); ?></label>
					</td>
				</tr>
				
				<?php
				/**
				 * Your Twitter Link
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Enter your Twitter URL', 'beautifuldecay' ); ?></th>
					<td>
						<input id="beautifuldecay_theme_options[twitterurl]" class="regular-text" type="text" name="beautifuldecay_theme_options[twitterurl]" value="<?php echo esc_url( $options['twitterurl'] ); ?>" />
						<label class="description" for="beautifuldecay_theme_options[twitterurl]"><?php _e( 'Leave blank to hide Twitter Icon', 'beautifuldecay' ); ?></label>
					</td>
				</tr>
	
				
			</table>

			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e( 'Save Options', 'beautifuldecay' ); ?>" />
			</p>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function beautifuldecay_options_validate( $input ) {


	// Our text option must be safe text with no HTML tags
	$input['twitterurl'] = wp_filter_nohtml_kses( $input['twitterurl'] );
	$input['facebookurl'] = wp_filter_nohtml_kses( $input['facebookurl'] );
	
	// Encode URLs
	$input['twitterurl'] = esc_url_raw( $input['twitterurl'] );
	$input['facebookurl'] = esc_url_raw( $input['facebookurl'] );
	
	return $input;
}
?>